@@ -19,20 +19,20 @@ if __name__ == "__main__":
 	p.mail="alexey@iias.spb.su"
 	p.description="Application for intelligent conference organisation"
 	p.url = "http://www.spiiras.nw.ru/"
-	p.depends = "python-gtk2|python2.5-gtk2, python-hildon|python2.5-hildon, kmplayer|vlc, python2.5-dbus|python-dbus, python2.5-imaging|python-imaging"
+	p.depends = "python-gtk2|python2.5-gtk2, python-hildon|python2.5-hildon, kmplayer|vlc, python-dbus|python2.5-dbus, python-imaging|python2.5-imaging"
 	p.section="user/tools"
 	p.license="gpl"
 	p.icon = "/home/user/MyDocs/agenda_project/agenda.png"
 	p.arch="all"                #should be all for python, any for all arch
 	p.urgency="low"             #not used in maemo onl for deb os
-	p.distribution="chinook,diablo"
+	p.distribution="chinook,diablo,fremantle"
 	p.repository="extras-devel"
 	p.xsbc_bugtracker="http://bugs.maemo.org"
 
 
 
 	version = "2.0"           #Version of your software, e.g. "1.2.0" or "0.8.2"
-	build = "2"                
+	build = "3"                
 	changeloginformation = "Alpha version" 
 	dir_name = "src"            
 	for root, dirs, files in os.walk(dir_name):
